@@ -343,6 +343,7 @@ QString program = "/opt/maemo/usr/games/"+selected_core;
 QStringList arguments;
 QProcess *myProcess = new QProcess();
 
+if (selected_core!="pcsx"){
 arguments << "-runcd"<<"-load"<<QString("%1").arg(save_slot);
 
 
@@ -358,9 +359,11 @@ if (abbm->isChecked())arguments<<"-abbeyfix";
 if (fscr->isChecked())arguments<<"-fullscreen";
 if (accelm->isChecked())arguments<<"-accel";
 
-
-if (selected_core=="pcsx")
+}else{
+	
+	if (ui->checkBox->isChecked())arguments<<"-nosound";
     arguments<<"-cdfile";
+}
 
 /*if (ldbg->isChecked()){
     arguments<<"-psxout";
